@@ -175,13 +175,30 @@ namespace
     IChecksumOnlyStream( buffer_type* Buffer,
 			 bool AutoDelete = true );
     
+    IChecksumOnlyStream( FrameCPP::Common::IStream& Source );
+    
     header_type	Header;
+  private:
+    void init( );
   };
 
   IChecksumOnlyStream::
   IChecksumOnlyStream( buffer_type* Buffer,
 		       bool AutoDelete )
     : IStream( Buffer, AutoDelete )
+  {
+    init( );
+  }
+
+  IChecksumOnlyStream::
+  IChecksumOnlyStream( FrameCPP::Common::IStream& Source )
+    : IStream( Source.rdbuf( ), false )
+  {
+    init( );
+  }
+    
+  void IChecksumOnlyStream::
+  init( )
   {
     using FrameCPP::Common::FrameSpec;
 
@@ -391,6 +408,12 @@ Verify::error_type Verify::
 operator()( IFrameStream& Stream,
 	    frame_filename_ptr_type& Filename )
 {
+  if ( CheckFileChecksumOnly( ) )
+  {
+    IChecksumOnlyStream	stream( Stream );
+
+    return crc_file_checksum_only( stream, stream.Header );
+  }
   //---------------------------------------------------------------------
   // Do initialization
   //---------------------------------------------------------------------
@@ -409,37 +432,21 @@ operator()( IFrameStream& Stream,
       throw VerifyException( VerifyException::FILE_OPEN_ERROR );
     }
 
-    if ( ! CheckFileChecksumOnly( ) )
+    CheckSumFilter* cs( Stream.GetCheckSumFile( ) );
+
+    Stream.rdbuf( )->FilterRemove( cs );
+    try
     {
-      CheckSumFilter* cs( Stream.GetCheckSumFile( ) );
-
-      Stream.rdbuf( )->FilterRemove( cs );
-      try
-	{
-	  toc = Stream.GetTOC( );
-	}
-      catch( ... )
-	{
-	}
-      Stream.rdbuf( )->FilterAdd( cs );
+      toc = Stream.GetTOC( );
     }
-
-
-    if ( CheckFileChecksumOnly( ) )
+    catch( ... )
     {
-      CheckSum::kind_type
-	file_checksum( CheckSum::CRC );
-
-      if ( Stream.Version( ) >= 8 )
-      {
-	/// \todo Need to modify the FrHeader to have virtual to get
-	/// \todo this information. Currently assume CRC
-	file_checksum = CheckSum::CRC;
-      }
-      Stream.SetCheckSumFile( file_checksum );
     }
-    else if ( ( CheckFast( ) == false )
-	      || ( Stream.Version( ) < 8 ) )
+    Stream.rdbuf( )->FilterAdd( cs );
+
+
+    if ( ( CheckFast( ) == false )
+	 || ( Stream.Version( ) < 8 ) )
     {
       //-----------------------------------------------------------------
       // Remove checksumming is not requested
@@ -472,12 +479,9 @@ operator()( IFrameStream& Stream,
     //-------------------------------------------------------------------
     // Determine if fast checking should be done.
     //-------------------------------------------------------------------
-    if ( CheckFileChecksumOnly( ) )
-    {
-    }
-    else if ( ( CheckFast( ) == true )
-	      && ( Stream.Version( ) >= 8 )
-	      && ( toc != (FrTOC*)NULL ) )
+    if ( ( CheckFast( ) == true )
+	 && ( Stream.Version( ) >= 8 )
+	 && ( toc != (FrTOC*)NULL ) )
     {
       //-----------------------------------------------------------------
       // All conditions have been satisfied to do fast checking
